@@ -194,8 +194,8 @@ sub generate_method {
         ;
     }
   }
-  if (my $pred = $spec->{builder_sub}) {
-    _install_coderef( "${into}::$spec->{builder}" => $spec->{builder_sub} );
+  if (my $builder = delete $spec->{builder_sub}) {
+    _install_coderef( "${into}::$spec->{builder}" => $builder );
   }
   if (my $cl = $spec->{clearer}) {
     _die_overwrite($into, $cl, 'a clearer')
@@ -572,10 +572,10 @@ sub _generate_populate_set {
     $spec->{trigger}
   ) : undef;
   if ($has_default) {
-    "($set)," . ($trigger ? "($test and $trigger)," : '')
+    "($set)," . ($trigger && $test ? "($test and $trigger)," : '') . "\n";
   }
   else {
-    "($test and ($set)" . ($trigger ? ", ($trigger)" : '') . "),";
+    "($test and ($set)" . ($trigger ? ", ($trigger)" : '') . "),\n";
   }
 }
 
