@@ -3,9 +3,11 @@ package Moo::sification;
 use Moo::_strictures;
 no warnings 'once';
 use Devel::GlobalDestruction qw(in_global_destruction);
+use Carp qw(croak);
+BEGIN { our @CARP_NOT = qw(Moo::HandleMoose) }
 
 sub unimport {
-  die "Can't disable Moo::sification after inflation has been done"
+  croak "Can't disable Moo::sification after inflation has been done"
     if $Moo::HandleMoose::SETUP_DONE;
   our $disabled = 1;
 }
